==> codeview-0.0.1.tar.gz: lib/codeview.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class P extends StatefulWidget {
  final String text;

  const P({
    Key? key,
    required this.text,
  }) : super(key: key);

  @override
  State<P> createState() => _PState();
}

class _PState extends State<P> {
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(10),
      child: Text(
        widget.text,
        style: TextStyle(fontSize: 14, wordSpacing: 1.5, height: 1.5),
      ),
    );
  }
}

class H extends StatefulWidget {
  final String text;

  const H({
    Key? key,
    required this.text,
  }) : super(key: key);

  @override
  State<H> createState() => _HState();
}

class _HState extends State<H> {
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(10),
      child: Text(
        widget.text,
        style: TextStyle(
            fontSize: 18,
            wordSpacing: 1.5,
            height: 1.5,
            fontWeight: FontWeight.bold),
      ),
    );
  }
}

class CodeView extends StatefulWidget {
  final String code;

  const CodeView({
    Key? key,
    required this.code,
  }) : super(key: key);

  @override
  State<CodeView> createState() => _CodeViewState();
}

class _CodeViewState extends State<CodeView> {
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(10),
      decoration: BoxDecoration(
        color: Colors.grey.withOpacity(.1),
        borderRadius: BorderRadius.circular(25),
      ),
      child: Container(
        constraints: const BoxConstraints(
          minHeight: 100,
          maxHeight: 250,
        ),
        child: Stack(
          children: [
            Positioned(
              top: 0,
              right: 0,
              child: IconButton(
                icon: const Icon(Icons.copy),
                onPressed: () {
                  Clipboard.setData(ClipboardData(text: widget.code));
                  ScaffoldMessenger.of(context).hideCurrentSnackBar();

                  ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
                      behavior: SnackBarBehavior.floating,
                      content: Text("Copied")));
                },
              ),
            ),
            Center(
              child: SingleChildScrollView(
                  padding: const EdgeInsets.all(10),
                  child: SelectableText(widget.code)),
            ),
          ],
        ),
      ),
    );
  }
}

==> codeview-0.0.6.tar.gz: lib/codeview.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class P extends StatefulWidget {
  final String text;

  const P({
    Key? key,
    required this.text,
  }) : super(key: key);

  @override
  State<P> createState() => _PState();
}

class _PState extends State<P> {
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(10),
      child: Text(
        widget.text,
        style: const TextStyle(fontSize: 14, wordSpacing: 1.5, height: 1.5),
      ),
    );
  }
}

class H extends StatefulWidget {
  final String text;

  const H({
    Key? key,
    required this.text,
  }) : super(key: key);

  @override
  State<H> createState() => _HState();
}

class _HState extends State<H> {
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(10),
      child: Text(
        widget.text,
        style: const TextStyle(
            fontSize: 18,
            wordSpacing: 1.5,
            height: 1.5,
            fontWeight: FontWeight.bold),
      ),
    );
  }
}

class CodeView extends StatefulWidget {
  final String code;

  const CodeView({
    Key? key,
    required this.code,
  }) : super(key: key);

  @override
  State<CodeView> createState() => _CodeViewState();
}

class _CodeViewState extends State<CodeView> {
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(10),
      decoration: BoxDecoration(
        color: Colors.grey.withOpacity(.1),
        borderRadius: BorderRadius.circular(25),
      ),
      child: Container(
        constraints: const BoxConstraints(
          minHeight: 100,
          maxHeight: 250,
        ),
        child: Stack(
          children: [
            Positioned(
              top: 0,
              right: 0,
              child: IconButton(
                icon: const Icon(Icons.copy),
                onPressed: () {
                  Clipboard.setData(ClipboardData(text: widget.code));
                  ScaffoldMessenger.of(context).hideCurrentSnackBar();

                  ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
                      behavior: SnackBarBehavior.floating,
                      content: Text("Copied")));
                },
              ),
            ),
            Positioned(
              bottom: 0,
              right: 0,
              child: Text(
                "Length: " + widget.code.length.toString(),
              ),
            ),
            Center(
              child: SingleChildScrollView(
                  padding: const EdgeInsets.all(10),
                  child: SelectableText(widget.code)),
            ),
          ],
        ),
      ),
    );
  }
}
